@@ -81,18 +81,18 @@ GDK_AVAILABLE_IN_ALL
 guint32       gdk_x11_display_get_user_time (GdkDisplay *display);
 
 GDK_AVAILABLE_IN_ALL
-const gchar * gdk_x11_display_get_startup_notification_id         (GdkDisplay *display);
+const char * gdk_x11_display_get_startup_notification_id         (GdkDisplay *display);
 GDK_AVAILABLE_IN_ALL
 void          gdk_x11_display_set_startup_notification_id         (GdkDisplay  *display,
-                                                                   const gchar *startup_id);
+                                                                   const char *startup_id);
 GDK_AVAILABLE_IN_ALL
 void          gdk_x11_display_set_program_class                   (GdkDisplay  *display,
                                                                    const char  *program_class);
 
 GDK_AVAILABLE_IN_ALL
 void          gdk_x11_display_set_cursor_theme (GdkDisplay  *display,
-                                                const gchar *theme,
-                                                const gint   size);
+                                                const char *theme,
+                                                const int    size);
 
 GDK_AVAILABLE_IN_ALL
 void gdk_x11_display_broadcast_startup_message (GdkDisplay *display,
@@ -106,7 +106,7 @@ GDK_AVAILABLE_IN_ALL
 GdkX11Screen *gdk_x11_display_get_screen (GdkDisplay *display);
 
 GDK_AVAILABLE_IN_ALL
-GdkMonitor * gdk_x11_display_get_primary_monitor (GdkDisplay *display);
+GdkMonitor * gdk_x11_display_get_primary_monitor (GdkDisplay *self);
 
 GDK_AVAILABLE_IN_ALL
 void        gdk_x11_display_grab              (GdkDisplay *display);
@@ -115,23 +115,21 @@ void        gdk_x11_display_ungrab            (GdkDisplay *display);
 
 GDK_AVAILABLE_IN_ALL
 void        gdk_x11_display_set_surface_scale (GdkDisplay *display,
-                                               gint scale);
+                                               int scale);
 
 GDK_AVAILABLE_IN_ALL
 void                           gdk_x11_display_error_trap_push        (GdkDisplay *display);
 /* warn unused because you could use pop_ignored otherwise */
 GDK_AVAILABLE_IN_ALL
-G_GNUC_WARN_UNUSED_RESULT gint gdk_x11_display_error_trap_pop         (GdkDisplay *display);
+G_GNUC_WARN_UNUSED_RESULT int  gdk_x11_display_error_trap_pop         (GdkDisplay *display);
 GDK_AVAILABLE_IN_ALL
 void                           gdk_x11_display_error_trap_pop_ignored (GdkDisplay *display);
 
 GDK_AVAILABLE_IN_ALL
-void        gdk_x11_register_standard_event_type (GdkDisplay *display,
-                                                  gint        event_base,
-                                                  gint        n_events);
+void        gdk_x11_set_sm_client_id (const char *sm_client_id);
 
 GDK_AVAILABLE_IN_ALL
-void        gdk_x11_set_sm_client_id (const gchar *sm_client_id);
+GdkSurface * gdk_x11_display_get_default_group (GdkDisplay *display);
 
 G_END_DECLS
 
