@@ -25,7 +25,7 @@
 #error "Only <gtk/gtk.h> can be included directly."
 #endif
 
-#include <gtk/gtkbin.h>
+#include <gtk/gtkwidget.h>
 
 G_BEGIN_DECLS
 
@@ -41,12 +41,12 @@ typedef struct _GtkPopoverClass  GtkPopoverClass;
 
 struct _GtkPopover
 {
-  GtkBin parent;
+  GtkWidget parent;
 };
 
 struct _GtkPopoverClass
 {
-  GtkBinClass parent_class;
+  GtkWidgetClass parent_class;
 
   void (* closed)           (GtkPopover *popover);
   void (* activate_default) (GtkPopover *popover);
@@ -62,6 +62,12 @@ GType           gtk_popover_get_type (void) G_GNUC_CONST;
 GDK_AVAILABLE_IN_ALL
 GtkWidget *     gtk_popover_new             (void);
 
+GDK_AVAILABLE_IN_ALL
+void            gtk_popover_set_child       (GtkPopover         *popover,
+                                             GtkWidget          *child);
+GDK_AVAILABLE_IN_ALL
+GtkWidget *     gtk_popover_get_child       (GtkPopover         *popover);
+
 GDK_AVAILABLE_IN_ALL
 void            gtk_popover_set_pointing_to (GtkPopover         *popover,
                                              const GdkRectangle *rect);
