@@ -861,22 +861,19 @@ GtkStateFlags gtk_style_context_get_state    (GtkStyleContext *context);
 
 GDK_AVAILABLE_IN_ALL
 void          gtk_style_context_set_scale    (GtkStyleContext *context,
-                                              gint             scale);
+                                              int              scale);
 GDK_AVAILABLE_IN_ALL
-gint          gtk_style_context_get_scale    (GtkStyleContext *context);
-
-GDK_AVAILABLE_IN_ALL
-GList *  gtk_style_context_list_classes (GtkStyleContext *context);
+int           gtk_style_context_get_scale    (GtkStyleContext *context);
 
 GDK_AVAILABLE_IN_ALL
 void     gtk_style_context_add_class    (GtkStyleContext *context,
-                                         const gchar     *class_name);
+                                         const char      *class_name);
 GDK_AVAILABLE_IN_ALL
 void     gtk_style_context_remove_class (GtkStyleContext *context,
-                                         const gchar     *class_name);
+                                         const char      *class_name);
 GDK_AVAILABLE_IN_ALL
 gboolean gtk_style_context_has_class    (GtkStyleContext *context,
-                                         const gchar     *class_name);
+                                         const char      *class_name);
 
 GDK_AVAILABLE_IN_ALL
 void        gtk_style_context_set_display (GtkStyleContext *context,
@@ -886,7 +883,7 @@ GdkDisplay *gtk_style_context_get_display (GtkStyleContext *context);
 
 GDK_AVAILABLE_IN_ALL
 gboolean gtk_style_context_lookup_color (GtkStyleContext *context,
-                                         const gchar     *color_name,
+                                         const char      *color_name,
                                          GdkRGBA         *color);
 
 /* Some helper functions to retrieve most common properties */
@@ -903,15 +900,12 @@ GDK_AVAILABLE_IN_ALL
 void gtk_style_context_get_margin           (GtkStyleContext *context,
                                              GtkBorder       *margin);
 
-GDK_AVAILABLE_IN_ALL
-void gtk_style_context_reset_widgets        (GdkDisplay      *display);
-
 GDK_AVAILABLE_IN_ALL
 void        gtk_render_insertion_cursor
                                    (GtkStyleContext     *context,
                                     cairo_t             *cr,
-                                    gdouble              x,
-                                    gdouble              y,
+                                    double               x,
+                                    double               y,
                                     PangoLayout         *layout,
                                     int                  index,
                                     PangoDirection       direction);
